From 4e4fed193add8804f475344fadfa621de63e52d1 Mon Sep 17 00:00:00 2001
From: Michele Baldessari <michele@acksyn.org>
Date: Tue, 13 Feb 2024 10:46:33 +0100
Subject: [PATCH 1/2] fix: Drop lib{ssl,crypto}.so.1.1 workarounds in test
 container
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

Since 7ce342fb88579b560abf9e66ff20bc91f9d7048e we upgraded redis to
7.2.4 which does not link to old {ssl,crypto}.so.1.1 anymore:

    ❯ podman run -it --rm --net=host docker.io/library/redis:7.2.4@sha256:cc8b0b85fe6917a401334fd285f9a8d66fae231abcf13aadfd02975bf3924a47 bash -c "ldd /usr/local/bin/redis-cli /usr/local/bin/redis-server" | grep -i -e ssl -e crypto
            libssl.so.3 => /lib/x86_64-linux-gnu/libssl.so.3 (0x00007fb63d6cf000)
            libcrypto.so.3 => /lib/x86_64-linux-gnu/libcrypto.so.3 (0x00007fb63d24d000)
            libssl.so.3 => /lib/x86_64-linux-gnu/libssl.so.3 (0x00007f333dc9f000)
            libcrypto.so.3 => /lib/x86_64-linux-gnu/libcrypto.so.3 (0x00007f333d81d000)

This fixes the following breakage in `make build`:

    [6/6] STEP 17/28: COPY --from=redis /usr/lib/linux-gnu/libssl.so.1.1 /usr/lib/linux-gnu/
    Error: building at STEP "COPY --from=redis /usr/lib/linux-gnu/libssl.so.1.1 /usr/lib/linux-gnu/": checking on sources under "/home/michele/.local/share/containers/storage/overlay/4c8aa0061967e60ef25c6dcb51bc8868c35da68f9656d4996b87ebad9756cf65/merged": copier: stat: "/usr/lib/linux-gnu/libssl.so.1.1": no such file or directory
    make: *** [Makefile:252: test-tools-image] Error 125

Signed-off-by: Michele Baldessari <michele@acksyn.org>
---
 test/container/Dockerfile | 13 -------------
 1 file changed, 13 deletions(-)

diff --git a/test/container/Dockerfile b/test/container/Dockerfile
index 9db9a2b07..8bee82218 100644
--- a/test/container/Dockerfile
+++ b/test/container/Dockerfile
@@ -1,10 +1,5 @@
 FROM docker.io/library/redis:7.2.4@sha256:cc8b0b85fe6917a401334fd285f9a8d66fae231abcf13aadfd02975bf3924a47 as redis
 
-# There are libraries we will want to copy from here in the final stage of the
-# build, but the COPY directive does not have a way to determine system
-# architecture, so we create a symlink here to facilitate copying.
-RUN ln -s /usr/lib/$(uname -m)-linux-gnu /usr/lib/linux-gnu 
-
 # Please make sure to also check the contained yarn version and update the references below when upgrading this image's version
 FROM docker.io/library/node:21.6.1@sha256:abc4a25c8b5a2b460f3144aabfc8941ecd7e4fb721e0b14b635e70394c1899fb as node
 
@@ -70,14 +65,6 @@ COPY ./test/fixture/testrepos/ssh_host_*_key* /etc/ssh/
 # Copy redis binaries to the image
 COPY --from=redis /usr/local/bin/* /usr/local/bin/
 
-# Copy redis dependencies/shared libraries
-# Ubuntu 22.04+ has moved to OpenSSL3 and no longer provides these libraries
-COPY --from=redis /usr/lib/linux-gnu/libssl.so.1.1 /usr/lib/linux-gnu/
-COPY --from=redis /usr/lib/linux-gnu/libcrypto.so.1.1 /usr/lib/linux-gnu/
-RUN mv /usr/lib/linux-gnu/libssl.so.1.1 /usr/lib/$(uname -m)-linux-gnu/ && \
-    mv /usr/lib/linux-gnu/libcrypto.so.1.1 /usr/lib/$(uname -m)-linux-gnu/ && \
-    rm -rf /usr/lib/linux-gnu/
-
 # Copy registry binaries to the image
 COPY --from=registry /bin/registry /usr/local/bin/
 COPY --from=registry /etc/docker/registry/config.yml /etc/docker/registry/config.yml
-- 
2.43.2

